.. _api_reference:

API reference
=============

:Release: |release|
:Date: |date|

You can find the implementation and documentation of every 
class and function of grogupy in this reference. The method 
and submodule index can be found :ref:`here <genindex>` and 
:ref:`here <modindex>` respectively.

.. toctree::
   :maxdepth: 2
   
   physics
   core
   io
   batch
   cli
   viz


.. automodule:: grogupy
   :noindex:
   :no-members:
   :no-undoc-members:
   :no-inherited-members:
   :no-imported-members:
